import {RcsbFv3DCustom, RcsbFv3DCustomInterface} from "../../RcsbFv3D/RcsbFv3DCustom";
import { DebugUtil } from "./tmdet-extension/debug-utils";
import { createFeatureViewerConfing } from "./FeatureViewConfig";
import { registerRegionDescriptorData } from "./UniTmpHelper";
import { TmDetDescriptorCache } from "./tmdet-extension/prop";
import { applyTransformations } from "./tmdet-extension/transformation";
import { PluginContext } from "molstar/lib/mol-plugin/context";
import { StateTransforms } from "molstar/lib/mol-plugin-state/transforms";
import { Vec3 } from "molstar/lib/mol-math/linear-algebra";

export { DebugUtil };

document.addEventListener("DOMContentLoaded", (event) => {
    (async function(event) {

        DebugUtil.enableLog();

        const pdbEntry = "1afo";
        const labelAsymId = "B";
        const params = {
            side1: "Inside",
            htpEntry: "GLPA_HUMAN",
            pdbEntry: pdbEntry,
            labelAsymId: labelAsymId,
            pdbtmEntry: `${pdbEntry}_${labelAsymId}`
        };

        const descriptorUrl = `/${pdbEntry}.json`;
        registerRegionDescriptorData(descriptorUrl, params.side1 as any);

        const { sequenceConfig, molstarConfig } = await createFeatureViewerConfing(params);
        const panel3dConfig: RcsbFv3DCustomInterface = {
            elementId: "null",
            sequencePanelConfig: sequenceConfig,
            structurePanelConfig: molstarConfig
        };
        molstarConfig.structureViewerConfig.viewerProps.layoutShowSequence = true;
        (molstarConfig as any).loadConfig.loadParams.params = {
            preset: { modelIndex: 0 }
        }
        DebugUtil.log('Panel config', panel3dConfig);

        const panel3d = new RcsbFv3DCustom(panel3dConfig);
        panel3d.render();

        setTimeout(() => {
                const descriptor = TmDetDescriptorCache.get('1afo');
                const plugin = (window as any).plugin as PluginContext;
                applyTransformations(plugin, descriptor!);
                plugin.state.data.build().to('assembly')
                    .apply(StateTransforms.Model.TransformStructureConformation, {
                            transform: {
                                name: 'components',
                                params: { axis: Vec3.unitY, angle: 90, translation: Vec3.zero() }
                            }
                        })
                    .commit();

            },
            2000
        );
    })();
});
